#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['podsearch']

package_data = \
{'': ['*']}

setup(name='podsearch',
      version='0.1.1',
      description="Let's find some podcasts!",
      author='Anton Zhiyanov',
      author_email='m@antonz.ru',
      url='https://github.com/nalgeon/podsearch-py',
      packages=packages,
      package_data=package_data,
      python_requires='>=3.6',
     )
